@@ -18,11 +18,11 @@ no_arg = object()
 
 
 class MultipleObjectsReturned(Exception):
-    """The requested object does not exist."""
+    """The query returned multiple objects when only one was expected."""
 
 
 class ObjectDoesNotExist(Exception):
-    """The query returned multiple objects when only one was expected."""
+    """The requested object does not exist."""
 
 
 def keygetter(
@@ -317,7 +317,7 @@ class OpNotFound(ValueError):
         return super().__init__(f"{op} not in LOOKUP_NAME_MAP")
 
 
-class QueryList(t.Generic[T], list[T]):
+class QueryList(list[T], t.Generic[T]):
     """Filter list of object/dictionaries. For small, local datasets.
 
     *Experimental, unstable*.
