@@ -1,4 +1,5 @@
 """Registry of VCS URL Parsers for libvcs."""
+
 import typing as t
 
 from libvcs._internal.module_loading import import_string
@@ -32,7 +33,7 @@ class VCSRegistry:
 
     parser_map: t.ClassVar["ParserMap"] = {}
 
-    def __init__(self, parsers: "ParserLazyMap"):
+    def __init__(self, parsers: "ParserLazyMap") -> None:
         for k, v in parsers.items():
             if isinstance(v, str):
                 v = import_string(v)
