@@ -23,12 +23,11 @@ import re
 from typing import Optional
 
 from libvcs._internal.dataclasses import SkipDefaultFieldsReprMixin
-from libvcs.url.git import RE_PIP_REV, SCP_REGEX
 
 from .base import Rule, RuleMap, URLProtocol
+from .constants import RE_PIP_REV, RE_SCP, RE_USER
 
 RE_PATH = r"""
-    ((?P<user>[^/:@]+)@)?
     (?P<hostname>([^/:@]+))
     (:(?P<port>\d{1,5}))?
     (?P<separator>[:,/])?
@@ -56,6 +55,7 @@ DEFAULT_RULES: list[Rule] = [
             rf"""
         ^{RE_SCHEME}
         ://
+        {RE_USER}
         {RE_PATH}
         {RE_PIP_REV}?
         """,
@@ -68,7 +68,8 @@ DEFAULT_RULES: list[Rule] = [
         pattern=re.compile(
             rf"""
         ^(?P<scheme>ssh)?
-        {SCP_REGEX}
+        {RE_USER}
+        {RE_SCP}
         {RE_PIP_REV}?
         """,
             re.VERBOSE,
@@ -101,6 +102,7 @@ PIP_DEFAULT_RULES: list[Rule] = [
             rf"""
         ^{RE_PIP_SCHEME}
         ://
+        {RE_USER}
         {RE_PATH}
         {RE_PIP_REV}?
         """,
@@ -143,7 +145,10 @@ Notes
 
 
 @dataclasses.dataclass(repr=False)
-class SvnBaseURL(URLProtocol, SkipDefaultFieldsReprMixin):
+class SvnBaseURL(
+    URLProtocol,
+    SkipDefaultFieldsReprMixin,
+):
     """SVN repository location. Parses URLs on initialization.
 
     Examples
@@ -275,7 +280,11 @@ class SvnBaseURL(URLProtocol, SkipDefaultFieldsReprMixin):
 
 
 @dataclasses.dataclass(repr=False)
-class SvnPipURL(SvnBaseURL, URLProtocol, SkipDefaultFieldsReprMixin):
+class SvnPipURL(
+    SvnBaseURL,
+    URLProtocol,
+    SkipDefaultFieldsReprMixin,
+):
     """Supports pip svn URLs."""
 
     # commit-ish (rev): tag, branch, ref
@@ -336,7 +345,12 @@ class SvnPipURL(SvnBaseURL, URLProtocol, SkipDefaultFieldsReprMixin):
 
 
 @dataclasses.dataclass(repr=False)
-class SvnURL(SvnPipURL, SvnBaseURL, URLProtocol, SkipDefaultFieldsReprMixin):
+class SvnURL(
+    SvnPipURL,
+    SvnBaseURL,
+    URLProtocol,
+    SkipDefaultFieldsReprMixin,
+):
     """Batteries included URL Parser. Supports svn(1) and pip URLs.
 
     **Ancestors (MRO)**
